@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 """
 ==============
 Reconfigurator
@@ -31,9 +31,9 @@ import argparse
 
 import nestifydict as nd
 
-from reconfigurator.compiler import *
+from compiler import *
 
-RECONFIGURATOR_CONFIG_FILE = "config/config.json"
+RECONFIGURATOR_CONFIG_FILE = "/config/config.json"
 
 __all__ = ["replace_file", "merge_file", "update_file", "update", "print_config_file", "print_config", "compile_config_file"]
 
@@ -45,7 +45,7 @@ def replace_file(sink_file : str, source_file : str):
     :param sink_file: (str) location of new to write into
     :param source_file: (str) location of file to write from
     """
-    with open(RECONFIGURATOR_CONFIG_FILE, "rb") as f:
+    with open(current + RECONFIGURATOR_CONFIG_FILE, "rb") as f:
         config = json.load(f)
         abs_path = config["abs_path"]
     source_file = abs_path + source_file
@@ -73,7 +73,7 @@ def compile_config_file(config_file : str):
 
     :param config_file: (str) location of file to compile
     """
-    with open(RECONFIGURATOR_CONFIG_FILE, "rb") as f:
+    with open(current + RECONFIGURATOR_CONFIG_FILE, "rb") as f:
         config = json.load(f)
         abs_path = config["abs_path"]
     temp_file = abs_path + config_file
@@ -81,7 +81,7 @@ def compile_config_file(config_file : str):
     config = compile_to_list(config)
     file_ext = config_file.split(".")[-1]
     file_name = config_file.split(".")[0]
-    config_file = abs_path + config_file + "_c" + file_ext
+    config_file = abs_path + config_file + "_c." + file_ext
     write_file(config_file, config)
 
         
@@ -94,7 +94,7 @@ def update_file(var, val, file : str, update_all : bool = False):
     :param file: (str) location of file
     :param update_all: (bool) if true, accepts var as a list of keys, *default*: False
     """
-    with open(RECONFIGURATOR_CONFIG_FILE, "rb") as f:
+    with open(current + RECONFIGURATOR_CONFIG_FILE, "rb") as f:
         config = json.load(f)
         abs_path = config["abs_path"]
     file = abs_path + file
@@ -127,7 +127,7 @@ def print_config_file(file : str):
     
     :param file: (str) Location of configuration params
     """
-    with open(RECONFIGURATOR_CONFIG_FILE, "rb") as f:
+    with open(current + RECONFIGURATOR_CONFIG_FILE, "rb") as f:
         config = json.load(f)
         abs_path = config["abs_path"]
     file = abs_path + file
@@ -155,9 +155,10 @@ def set_abs_path(path : str = ""):
     
     :param path: (str)
     """ 
-    with open(RECONFIGURATOR_CONFIG_FILE, "r+") as f:
+    with open(current + RECONFIGURATOR_CONFIG_FILE, "rb") as f:
         data = json.load(f)
         data["abs_path"] = path
+    with open(current + RECONFIGURATOR_CONFIG_FILE, "w") as f:
         json.dump(data,f)
         
 def reset_abs_path():
@@ -201,29 +202,29 @@ def write_file(sink_file: str, params: dict):
 if __name__=='__main__':  
     
     parser = argparse.ArgumentParser(description='Reconfigurator CLI')
-    parser.add_argument('-p',  '--print',   type=str, nargs = 1, help='prints configuration from specified file')
+    parser.add_argument('-p',  '--print_file',   type=str, nargs = 1, help='prints configuration from specified file')
     parser.add_argument('-s',  '--set',     type=str, nargs = 1, help='Sets absolute path to specified')
     parser.add_argument('-rs', '--reset',   action="store_const", const=True, help='Reset absolute path to absolute')
     parser.add_argument('-r',  '--replace', type=str, nargs = 2, help='Replaces config file with another: Should specify sink_file source_file')
     parser.add_argument('-m',  '--merge',   type=str, nargs="+", help='Merges config files: Earlier files take precendence')
-    parser.add_argument('-mr', '--merge-recursive',   type=str, nargs="+", help='Merges config files and iterables within them, last file will be destination')
+    parser.add_argument('-mr', '--merge_recursive',   type=str, nargs="+", help='Merges config files and iterables within them, last file will be destination')
     parser.add_argument('-u',  '--update',  type=str, nargs='+', help='Updates variables in a file: Should specify file key val key2 val2 ...')
     parser.add_argument('-c',  '--compile',  type=str, nargs = 1, help='Compiles a configuration: Should specify file')
 
     args = parser.parse_args()
     
-    if hasattr(args, "print") and args.print is not None:
-        print_config_file(getattr(args,"print")[0])
-    if hasattr(args, "setpath") and args.setpath is not None:
-        set_abs_path(getattr(args,"setpath")[0])
+    if hasattr(args, "print_file") and args.print_file is not None:
+        print_config_file(getattr(args,"print_file")[0])
+    if hasattr(args, "set") and args.set is not None:
+        set_abs_path(getattr(args,"set")[0])
     if hasattr(args, "reset") and args.reset:
         reset_abs_path()
     if hasattr(args, "replace") and args.replace is not None:
         replace_file(getattr(args,"replace")[0],getattr(args,"replace")[1])
     if hasattr(args, "merge") and args.merge is not None:
         merge_file(getattr(args,"merge"))  
-    if hasattr(args, "merge-recursive") and args.merge_recursive is not None:
-        merge_file(getattr(args,"merge-recrusive"), True)  
+    if hasattr(args, "merge_recursive") and args.merge_recursive is not None:
+        merge_file(getattr(args,"merge_recrusive"), True)  
     if hasattr(args, "update") and args.update is not None:
         val = []
         var = []
